@@ -119,6 +119,11 @@ return [
 			'url' => '/api/messages/{id}/attachment/{attachmentId}',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'messages#downloadAttachments',
+			'url' => '/api/messages/{id}/attachments',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'messages#saveAttachment',
 			'url' => '/api/messages/{id}/attachment/{attachmentId}',
@@ -204,6 +209,21 @@ return [
 			'url' => '/api/trustedsenders',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'sieve#updateAccount',
+			'url' => '/api/sieve/account/{id}',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'sieve#getActiveScript',
+			'url' => '/api/sieve/active/{id}',
+			'verb' => 'GET'
+		],
+		[
+			'name' => 'sieve#updateActiveScript',
+			'url' => '/api/sieve/active/{id}',
+			'verb' => 'PUT'
+		]
 	],
 	'resources' => [
 		'accounts' => ['url' => '/api/accounts'],
