@@ -6,6 +6,7 @@ OC.L10N.register(
     "Creating account failed: " : "Tilin luominen epäonnistui:",
     "Embedded message %s" : "Upotettu viesti %s",
     "Important mail" : "Tärkeä sähköposti",
+    "Unread mail" : "Lukematon sähköposti",
     "Mails" : "Sähköpostit",
     "Mail" : "Sähköposti",
     "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
@@ -37,7 +38,9 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "Allekirjoitus lisätään uusien viestien ja vastausten tekstiosaan.",
     "Writing mode" : "Kirjoitustila",
     "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
+    "Default folders" : "Oletuskansiot",
     "Mail server" : "Sähköpostipalvelin",
+    "Trusted senders" : "Luotetut lähettäjät",
     "Add alias" : "Lisää alias",
     "Add mail account" : "Lisää sähköpostitili",
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
@@ -81,14 +84,10 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
     "Set up an account" : "Määritä tili",
     "Plain text" : "Raakateksti",
+    "Rich text" : "Rikas teksti",
     "No messages" : "Ei viestejä",
     "Draft: " : "Luonnos: ",
     "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
-    "Mark {number} unread" : "Merkkaa {number} lukemattomiksi",
-    "Mark {number} read" : "Merkkaa {number} luetuiksi",
-    "Favorite {number}" : "Merkkaa {number} suosikeiksi",
-    "Move {number}" : "Siirrä {number} viestiä",
-    "Delete {number}" : "Poista {number} viestiä",
     "Load more" : "Lataa lisää",
     "Could not delete message" : "Ei voitu poistaa viestiä",
     "Report this bug" : "Ilmoita viasta",
@@ -96,16 +95,21 @@ OC.L10N.register(
     "Loading messages" : "Ladataan viestejä",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
     "Choose" : "Valitse",
+    "Important and unread" : "Tärkeät ja ei luetut",
     "Important info" : "Tärkeää tietoa",
     "Favorites" : "Suosikit",
     "Other" : "Muu",
+    "Notify the sender" : "Ilmoita lähettäjälle",
     "Reply to sender only" : "Vastaa vain lähettäjälle",
     "Forward" : "Lähetä edelleen",
     "Edit as new message" : "Muokkaa uutena viestinä",
+    "Mark unimportant" : "Merkitse ei tärkeäksi",
     "Mark important" : "Merkitse tärkeäksi",
+    "Mark unfavorite" : "Merkitse ei suosikiksi",
     "Mark favorite" : "Merkitse suosikiksi",
     "Mark unread" : "Merkitse lukemattomaksi",
     "Mark read" : "Merkitse luetuksi",
+    "Mark not spam" : "Merkitse ei roskapostiksi",
     "Mark as spam" : "Merkitse roskapostiksi",
     "Unselect" : "Poista valinta",
     "Select" : "Valitse",
@@ -113,6 +117,7 @@ OC.L10N.register(
     "View source" : "Näytä lähde",
     "Delete" : "Poista",
     "Message source" : "Viestin lähde",
+    "Message body" : "Viestin runko",
     "Attachments" : "Liitteet",
     "Import into calendar" : "Tuo kalenteriin",
     "Download attachment" : "Lataa liite",
@@ -121,10 +126,10 @@ OC.L10N.register(
     "Embedded message" : "Upotettu viesti",
     "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
     "Save all to Files" : "Tallenna kaikki tiedostoihin",
+    "Download Zip" : "Lataa Zip",
     "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tämä viesti on salattu PGP:llä. Asenna Mailvelope purkaaksesi viestin salauksen.",
     "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
-    "Show images from this sender" : "Näytä kuvat tältä lähettäjältä",
     "Message frame" : "Viestiruutu",
     "Quoted text" : "Lainattu teksti",
     "Moving" : "Siirretään",
@@ -157,10 +162,17 @@ OC.L10N.register(
     "Could not load your draft" : "Luonnosta ei voitu ladata",
     "Could not load original message" : "Alkuperäistä viestiä ei voitu ladata",
     "No message selected" : "Viestiä ei ole valittu",
+    "Disabled" : "Pois käytöstä",
+    "Enabled" : "Käytössä",
+    "Custom" : "Omavalintainen",
+    "Oh Snap!" : "Oho!",
     "Signature …" : "Allekirjoitus…",
     "Save signature" : "Tallenna allekirjoitus",
     "Could not load your message thread" : "Viestiketjua ei voitu ladata",
     "Reply" : "Vastaa",
+    "Remove" : "Poista",
+    "individual" : "yksittäinen",
+    "domain" : "domaini",
     "Import into {calendar}" : "Tuo kalenteriin {calendar}",
     "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
     "Could not create event" : "Tapahtumaa ei voitu luoda",
@@ -197,6 +209,7 @@ OC.L10N.register(
     "All" : "Kaikki",
     "Archive" : "Arkisto",
     "Drafts" : "Luonnokset",
+    "Priority inbox" : "Tärkeät saapuneet",
     "All inboxes" : "Kaikki saapuneiden laatikot",
     "Inbox" : "Saapuneet",
     "Junk" : "Roskaposti",
