@@ -5,8 +5,11 @@ OC.L10N.register(
     "Creating account failed: " : "La creacion del compte a fracassat :",
     "Mail" : "Mail",
     "Name" : "Nom",
+    "Mail Address" : "Adreça mail",
     "Password" : "Senhal",
     "None" : "Pas cap",
+    "IMAP Password" : "Senhal IMAP",
+    "SMTP Password" : "Senhal SMTP",
     "Save" : "Salvar",
     "Connect" : "Connectar",
     "Write message …" : "Escriure un messatge…",
@@ -41,6 +44,7 @@ OC.L10N.register(
     "Junk" : "Indesirables",
     "Sent" : "Mandats",
     "Trash" : "Escobilhièr",
+    "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Error loading message" : "Error al moment del cargament del messatge",
     "Continue to %s" : "Contunhar cap a %s"
