@@ -45,6 +45,8 @@ OC.L10N.register(
     "Default folders" : "預設資料夾",
     "The folders to use for drafts, sent messages and deleted messages." : "用於草稿、寄件備份與已刪除郵件要使用的資料夾。",
     "Mail server" : "郵件伺服器",
+    "Sieve filter server" : "過濾伺服器",
+    "Sieve filter rules" : "過濾規則",
     "Trusted senders" : "信任的寄件者",
     "Add alias" : "新增別名",
     "Add mail account" : "新增郵件帳號",
@@ -52,6 +54,7 @@ OC.L10N.register(
     "Register as application for mail links" : "註冊為郵件連結的處理應用程式",
     "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
+    "Put my text to the bottom of a reply instead of on top of it." : "將我的文字放在回覆的底部而非頂部。",
     "From" : "從",
     "Select account" : "選取帳號",
     "To" : "至",
@@ -99,17 +102,17 @@ OC.L10N.register(
     "No messages" : "沒有郵件",
     "Draft: " : "草稿：",
     "Blind copy recipients only" : "僅密件副本收件者",
-    "Mark {number} unread" : "將 {number} 標記為未讀",
-    "Mark {number} read" : "將 {number} 標記為已讀",
-    "Unfavorite {number}" : "取消我的最愛 {number}",
-    "Favorite {number}" : "我的最愛 {number}",
-    "Unselect {number}" : "取消選取 {number}",
-    "Move {number}" : "移動 {number}",
-    "Forward {number} as attachment" : "轉發 {number} 作為附件",
-    "Delete {number}" : "刪除 {number}",
     "Load more" : "載入更多",
     "No trash mailbox configured" : "未設定垃圾信箱",
     "Could not delete message" : "無法刪除郵件",
+    "_Mark {number} unread_::_Mark {number} unread_" : ["將 {number} 標記為未讀"],
+    "_Mark {number} read_::_Mark {number} read_" : ["將 {number} 標記為已讀"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消我的最愛 {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["我的最愛 {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["取消選取 {number}"],
+    "_Move {number}_::_Move {number}_" : ["移動 {number}"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["轉寄 {number} 作為附件"],
+    "_Delete {number}_::_Delete {number}_" : ["刪除 {number}"],
     "Report this bug" : "回報此臭蟲",
     "Could not open mailbox" : "無法開啟信箱",
     "Loading messages" : "正在載入郵件",
@@ -153,10 +156,12 @@ OC.L10N.register(
     "Embedded message" : "內嵌郵件",
     "Choose a folder to store the attachment in" : "選擇一個資料夾來存放附件",
     "Save all to Files" : "全部儲存至檔案",
+    "Download Zip" : "下載 Zip 壓縮檔",
     "Choose a folder to store the attachments in" : "選擇一個資料夾來存放附件",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此郵件使用 PGP 加密。安裝 Mailvelope 來解密。",
     "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入。",
-    "Show images from this sender" : "顯示來自此寄件者的圖片",
+    "Always show images from {sender}" : "一律顯示來自 {sender} 的圖片",
+    "Always show images from {domain}" : "一律顯示來自 {domain} 的圖片",
     "Message frame" : "郵件框",
     "Quoted text" : "引用文字",
     "Moving" : "正在移動",
@@ -176,7 +181,7 @@ OC.L10N.register(
     "Remove account {email}" : "移除帳號 {email}",
     "Remove {email}" : "移除 {email}",
     "Cancel" : "取消",
-    "Show all subscribed mailbox" : "顯示所有已訂閱的信箱",
+    "Show all subscribed mailboxes" : "顯示所有已訂閱的信箱",
     "Show all mailboxes" : "顯示所有信箱",
     "Collapse mailboxes" : "折疊信箱",
     "Mark all as read" : "全部標記為已讀",
@@ -198,11 +203,28 @@ OC.L10N.register(
     "Could not load your draft" : "無法載入您的草稿",
     "Could not load original message" : "無法載入原始郵件",
     "No message selected" : "未選取郵件",
+    "Disabled" : "已停用",
+    "Enabled" : "已啟用",
+    "Sieve Host" : "過濾主機",
+    "Sieve Security" : "過濾安全",
+    "Sieve Port" : "過濾連接埠",
+    "Sieve Credentials" : "過濾憑證",
+    "IMAP Credentials" : "IMAP 憑證",
+    "Custom" : "自訂",
+    "Sieve User" : "過濾使用者",
+    "Sieve Password" : "過濾密碼",
+    "Oh Snap!" : "喔喔！",
+    "Save sieve settings" : "儲存過濾設定",
+    "Save sieve script" : "儲存過濾指令稿",
     "Signature …" : "簽名……",
     "Save signature" : "儲存簽名",
     "Could not load your message thread" : "無法載入您的郵件串",
     "Reply" : "回覆",
     "Remove" : "移除",
+    "No senders are trusted at the moment." : "目前沒有寄件者受到信任。",
+    "Could not remove trusted sender {sender}" : "無法移除受信任的寄件者 {sender}",
+    "individual" : "個人",
+    "domain" : "網域",
     "Import into {calendar}" : "已匯入至 {calendar}",
     "Event imported into {calendar}" : "活動已匯入至 {calendar}",
     "Could not create event" : "無法建立活動",
@@ -218,6 +240,7 @@ OC.L10N.register(
     "Email: {email}" : "電子郵件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}:{port}（{ssl} 加密）",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP：{user} 在 {host}:{port}（{ssl} 加密）",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "過濾：{user} 在 {host}:{port}（{ssl} 加密）",
     "You can configure a template for account settings, from which all users will get an account provisioned from." : "您可以為帳號設定建立範本，所有使用者都可以從其中取得預先設定好的帳號。",
     "Provision an account for every user" : "為每個使用者設定一個帳號",
     "General" : "一般",
@@ -227,6 +250,8 @@ OC.L10N.register(
     "Host" : "主機",
     "Port" : "連接埠",
     "SMTP" : "SMTP",
+    "Sieve" : "過濾",
+    "Enable sieve integration" : "啟用過濾整合",
     "Apply and create/update for all users" : "為所有使用者套用並建立／更新",
     "Disable and un-provision existing accounts" : "停用並取消設定現有帳號",
     "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立帳號：",
