@@ -81,6 +81,12 @@ class Account implements JsonSerializable {
 		$this->memcacheFactory = OC::$server->getMemcacheFactory();
 	}
 
+	public function __destruct() {
+		if ($this->client !== null) {
+			$this->client->logout();
+		}
+	}
+
 	public function getMailAccount(): MailAccount {
 		return $this->account;
 	}
@@ -159,7 +165,11 @@ class Account implements JsonSerializable {
 			try {
 				$this->client->login();
 			} catch (Horde_Imap_Client_Exception $e) {
-				throw new ServiceException("Could not connect to IMAP: " . $e->getMessage(), $e->getCode(), $e);
+				throw new ServiceException(
+					"Could not connect to IMAP host $host:$port: " . $e->getMessage(),
+					(int) $e->getCode(),
+					$e
+				);
 			}
 		}
 		return $this->client;
@@ -175,8 +185,7 @@ class Account implements JsonSerializable {
 	public function getMailbox($folderId) {
 		return new Mailbox(
 			$this->getImapConnection(),
-			new Horde_Imap_Client_Mailbox($folderId),
-			[]
+			new Horde_Imap_Client_Mailbox($folderId)
 		);
 	}
 
