@@ -24,15 +24,16 @@ declare(strict_types=1);
 
 namespace OCA\Mail\AppInfo;
 
-use Exception;
 use Horde_Translation;
 use OCA\Mail\Contracts\IAttachmentService;
 use OCA\Mail\Contracts\IAvatarService;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IMailSearch;
 use OCA\Mail\Contracts\IMailTransmission;
+use OCA\Mail\Contracts\ITrustedSenderService;
 use OCA\Mail\Contracts\IUserPreferences;
-use OCA\Mail\Dashboard\MailWidget;
+use OCA\Mail\Dashboard\ImportantMailWidget;
+use OCA\Mail\Dashboard\UnreadMailWidget;
 use OCA\Mail\Events\DraftSavedEvent;
 use OCA\Mail\Events\MailboxesSynchronizedEvent;
 use OCA\Mail\Events\SynchronizationEvent;
@@ -59,6 +60,7 @@ use OCA\Mail\Service\AvatarService;
 use OCA\Mail\Service\MailManager;
 use OCA\Mail\Service\MailTransmission;
 use OCA\Mail\Service\Search\MailSearch;
+use OCA\Mail\Service\TrustedSenderService;
 use OCA\Mail\Service\UserPreferenceSevice;
 use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
@@ -69,6 +71,8 @@ use OCP\User\Events\UserDeletedEvent;
 use OCP\Util;
 use Psr\Container\ContainerInterface;
 
+include_once __DIR__ . '/../../vendor/autoload.php';
+
 class Application extends App implements IBootstrap {
 	public const APP_ID = 'mail';
 
@@ -77,10 +81,6 @@ class Application extends App implements IBootstrap {
 	}
 
 	public function register(IRegistrationContext $context): void {
-		if ((@include_once __DIR__ . '/../../vendor/autoload.php') === false) {
-			throw new Exception('Cannot include autoload. Did you run install dependencies using composer?');
-		}
-
 		$context->registerParameter('hostname', Util::getServerHostName());
 
 		$context->registerService('userFolder', function (ContainerInterface $c) {
@@ -95,6 +95,7 @@ class Application extends App implements IBootstrap {
 		$context->registerServiceAlias(IMailManager::class, MailManager::class);
 		$context->registerServiceAlias(IMailSearch::class, MailSearch::class);
 		$context->registerServiceAlias(IMailTransmission::class, MailTransmission::class);
+		$context->registerServiceAlias(ITrustedSenderService::class, TrustedSenderService::class);
 		$context->registerServiceAlias(IUserPreferences::class, UserPreferenceSevice::class);
 
 		$context->registerEventListener(DraftSavedEvent::class, DeleteDraftListener::class);
@@ -113,7 +114,8 @@ class Application extends App implements IBootstrap {
 		$context->registerMiddleWare(ErrorMiddleware::class);
 		$context->registerMiddleWare(ProvisioningMiddleware::class);
 
-		$context->registerDashboardWidget(MailWidget::class);
+		$context->registerDashboardWidget(ImportantMailWidget::class);
+		$context->registerDashboardWidget(UnreadMailWidget::class);
 		$context->registerSearchProvider(Provider::class);
 
 		// bypass Horde Translation system
