@@ -100,7 +100,12 @@ class Manager {
 									string $smtpUser,
 									string $smtpHost,
 									int $smtpPort,
-									string $smtpSslMode): void {
+									string $smtpSslMode,
+									bool $sieveEnabled,
+									string $sieveUser,
+									string $sieveHost,
+									int $sievePort,
+									string $sieveSslMode): void {
 		$config = $this->configMapper->save(new Config([
 			'active' => true,
 			'email' => $email,
@@ -112,6 +117,11 @@ class Manager {
 			'smtpHost' => $smtpHost,
 			'smtpPort' => $smtpPort,
 			'smtpSslMode' => $smtpSslMode,
+			'sieveEnabled' => $sieveEnabled,
+			'sieveUser' => $sieveUser,
+			'sieveHost' => $sieveHost,
+			'sievePort' => $sievePort,
+			'sieveSslMode' => $sieveSslMode,
 		]));
 
 		$this->provision($config);
@@ -119,10 +129,7 @@ class Manager {
 
 	private function updateAccount(IUser $user, MailAccount $account, Config $config): MailAccount {
 		$account->setEmail($config->buildEmail($user));
-		if ($user->getDisplayName() !== $user->getUID()) {
-			// Only set if it's something meaningful
-			$account->setName($user->getDisplayName());
-		}
+		$account->setName($user->getDisplayName());
 		$account->setInboundUser($config->buildImapUser($user));
 		$account->setInboundHost($config->getImapHost());
 		$account->setInboundPort($config->getImapPort());
@@ -131,6 +138,19 @@ class Manager {
 		$account->setOutboundHost($config->getSmtpHost());
 		$account->setOutboundPort($config->getSmtpPort());
 		$account->setOutboundSslMode($config->getSmtpSslMode());
+		$account->setSieveEnabled($config->getSieveEnabled());
+
+		if ($config->getSieveEnabled()) {
+			$account->setSieveUser($config->buildSieveUser($user));
+			$account->setSieveHost($config->getSieveHost());
+			$account->setSievePort($config->getSievePort());
+			$account->setSieveSslMode($config->getSieveSslMode());
+		} else {
+			$account->setSieveUser(null);
+			$account->setSieveHost(null);
+			$account->setSievePort(null);
+			$account->setSieveSslMode(null);
+		}
 
 		return $account;
 	}
