@@ -38,10 +38,9 @@ use OCA\Mail\IMAP\PreviewEnhancer;
 use OCA\Mail\IMAP\Sync\Response;
 use OCA\Mail\Service\Search\FilterStringParser;
 use OCA\Mail\Service\Search\SearchQuery;
-use OCP\AppFramework\Db\DoesNotExistException;
+use Psr\Log\LoggerInterface;
 use function array_diff;
 use function array_map;
-use function end;
 
 class SyncService {
 
@@ -60,60 +59,55 @@ class SyncService {
 	/** @var PreviewEnhancer */
 	private $previewEnhancer;
 
+	/** @var LoggerInterface */
+	private $logger;
+
 	public function __construct(ImapToDbSynchronizer $synchronizer,
 								FilterStringParser $filterStringParser,
 								MailboxMapper $mailboxMapper,
 								MessageMapper $messageMapper,
-								PreviewEnhancer $previewEnhancer) {
+								PreviewEnhancer $previewEnhancer,
+								LoggerInterface $logger) {
 		$this->synchronizer = $synchronizer;
 		$this->filterStringParser = $filterStringParser;
 		$this->mailboxMapper = $mailboxMapper;
 		$this->messageMapper = $messageMapper;
 		$this->previewEnhancer = $previewEnhancer;
+		$this->logger = $logger;
 	}
 
 	/**
 	 * @param Account $account
-	 * @param string $mailboxId
+	 * @param Mailbox $mailbox
 	 *
 	 * @throws MailboxLockedException
 	 * @throws ServiceException
 	 */
 	public function clearCache(Account $account,
-							   string $mailboxId): void {
-		try {
-			$mailbox = $this->mailboxMapper->find($account, $mailboxId);
-		} catch (DoesNotExistException $e) {
-			throw new ServiceException('Mailbox to sync does not exist in the database', 0, $e);
-		}
-
+							   Mailbox $mailbox): void {
 		$this->synchronizer->clearCache($account, $mailbox);
 	}
 
 	/**
 	 * @param Account $account
-	 * @param string $mailboxId
+	 * @param Mailbox $mailbox
 	 * @param int $criteria
-	 * @param array $knownUids
+	 * @param int[] $knownIds
 	 * @param bool $partialOnly
 	 *
+	 * @param string|null $filter
+	 *
 	 * @return Response
 	 * @throws ClientException
 	 * @throws MailboxNotCachedException
 	 * @throws ServiceException
 	 */
 	public function syncMailbox(Account $account,
-								string $mailboxId,
+								Mailbox $mailbox,
 								int $criteria,
-								array $knownUids,
+								array $knownIds,
 								bool $partialOnly,
 								string $filter = null): Response {
-		try {
-			$mailbox = $this->mailboxMapper->find($account, $mailboxId);
-		} catch (DoesNotExistException $e) {
-			throw new ServiceException('Mailbox to sync does not exist in the database', 0, $e);
-		}
-
 		if ($partialOnly && !$mailbox->isCached()) {
 			throw MailboxNotCachedException::from($mailbox);
 		}
@@ -121,53 +115,61 @@ class SyncService {
 		$this->synchronizer->sync(
 			$account,
 			$mailbox,
+			$this->logger,
 			$criteria,
-			$knownUids,
+			$this->messageMapper->findUidsForIds($mailbox, $knownIds),
 			!$partialOnly
 		);
 
 		$query = $filter === null ? null : $this->filterStringParser->parse($filter);
-
-		return $this->getDatabaseSyncChanges($account, $mailbox, $knownUids, $query);
+		return $this->getDatabaseSyncChanges(
+			$account,
+			$mailbox,
+			$knownIds,
+			$query
+		);
 	}
 
 	/**
 	 * @param Account $account
 	 * @param Mailbox $mailbox
-	 * @param array $knownUids
+	 * @param int[] $knownIds
 	 * @param SearchQuery $query
 	 *
 	 * @return Response
 	 * @todo does not work with text token search queries
 	 *
 	 */
-	private function getDatabaseSyncChanges(Account $account, Mailbox $mailbox, array $knownUids, ?SearchQuery $query): Response {
-		if (empty($knownUids)) {
-			$newUids = $this->messageMapper->findAllUids($mailbox);
+	private function getDatabaseSyncChanges(Account $account,
+											Mailbox $mailbox,
+											array $knownIds,
+											?SearchQuery $query): Response {
+		if (empty($knownIds)) {
+			$newIds = $this->messageMapper->findAllIds($mailbox);
 		} else {
-			sort($knownUids, SORT_NUMERIC);
-			$last = end($knownUids);
-			$newUids = $this->messageMapper->findNewUids($mailbox, $last);
+			$newIds = $this->messageMapper->findNewIds($mailbox, $knownIds);
 		}
 
 		if ($query !== null) {
 			// Filter new messages to those that also match the current filter
-			$newUids = $this->messageMapper->findUidsByQuery($mailbox, $query, null, $newUids);
+			$newUids = $this->messageMapper->findUidsForIds($mailbox, $newIds);
+			$newIds = $this->messageMapper->findIdsByQuery($mailbox, $query, null, $newUids);
 		}
-		$new = $this->messageMapper->findByUids($mailbox, $newUids);
+		$new = $this->messageMapper->findByIds($newIds);
 
 		// TODO: $changed = $this->messageMapper->findChanged($mailbox, $uids);
 		if ($query !== null) {
-			$changedUids = $this->messageMapper->findUidsByQuery($mailbox, $query, null, $knownUids);
+			$changedUids = $this->messageMapper->findUidsForIds($mailbox, $knownIds);
+			$changedIds = $this->messageMapper->findIdsByQuery($mailbox, $query, null, $changedUids);
 		} else {
-			$changedUids = $knownUids;
+			$changedIds = $knownIds;
 		}
-		$changed = $this->messageMapper->findByUids($mailbox, $changedUids);
+		$changed = $this->messageMapper->findByIds($changedIds);
 
-		$stillKnownUids = array_map(static function (Message $msg) {
-			return $msg->getUid();
+		$stillKnownIds = array_map(static function (Message $msg) {
+			return $msg->getId();
 		}, $changed);
-		$vanished = array_values(array_diff($knownUids, $stillKnownUids));
+		$vanished = array_values(array_diff($knownIds, $stillKnownIds));
 
 		return new Response(
 			$this->previewEnhancer->process($account, $mailbox, $new),
